"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.basicWebpackBabelConfig = exports.basicBrowserBabelConfig = exports.cjsBabelConfig = exports.esBabelConfig = exports.baseConfig = exports.presetEnvCjs = exports.presetEnvEs = void 0;
exports.getPresetEnv = getPresetEnv;
const browserslist_config_1 = __importDefault(require("@knapsack/browserslist-config"));
/**
 * Useful for Angular
 */
const decoratorPlugin = [
    require.resolve('@babel/plugin-proposal-decorators'),
    {
        version: '2023-11',
    },
];
function getPresetEnv(options) {
    return [require.resolve('@babel/preset-env'), options];
}
exports.presetEnvEs = getPresetEnv({
    modules: false,
    // Exclude transforms that make all code slower; borrowed from https://github.com/facebook/create-react-app/blob/9123aae7a3beaba8b245f73eb0180baa7b2f8411/packages/babel-preset-react-app/create.js#L90
    exclude: ['transform-typeof-symbol'],
    targets: {
        esmodules: true,
    },
});
exports.presetEnvCjs = getPresetEnv({
    modules: 'commonjs',
});
exports.baseConfig = {
    presets: [
        [
            require.resolve('@babel/preset-react'),
            {
                development: process.env.NODE_ENV !== 'production',
            },
        ],
        [
            require.resolve('@babel/preset-typescript'),
            {
                isTSX: true,
                allExtensions: true,
                jsxPragma: 'React',
            },
        ],
    ],
    plugins: [
        // https://www.npmjs.com/package/babel-plugin-transform-async-to-promises
        require.resolve('babel-plugin-transform-async-to-promises'),
        require.resolve('@babel/plugin-syntax-dynamic-import'),
        require.resolve('@babel/plugin-transform-object-rest-spread'),
        require.resolve('@babel/plugin-transform-nullish-coalescing-operator'),
        decoratorPlugin,
        require.resolve('@babel/plugin-transform-class-properties'),
        require.resolve('@babel/plugin-transform-optional-chaining'),
        require.resolve('@babel/plugin-transform-runtime'),
    ].filter(Boolean),
};
exports.esBabelConfig = {
    ...exports.baseConfig,
    presets: [...exports.baseConfig.presets, exports.presetEnvEs],
};
exports.cjsBabelConfig = {
    ...exports.baseConfig,
    presets: [...exports.baseConfig.presets, exports.presetEnvCjs],
};
exports.basicBrowserBabelConfig = {
    presets: [
        // https://babeljs.io/docs/en/babel-preset-env
        [require.resolve('@babel/preset-env'), { targets: browserslist_config_1.default }],
        [
            // https://babeljs.io/docs/en/babel-preset-typescript
            require.resolve('@babel/preset-typescript'),
            {
                isTSX: true,
                allExtensions: true,
            },
        ],
        [
            // https://babeljs.io/docs/en/babel-preset-react
            require.resolve('@babel/preset-react'),
            {
                development: process.env.NODE_ENV !== 'production',
            },
        ],
    ],
};
exports.basicWebpackBabelConfig = {
    presets: [
        // https://babeljs.io/docs/en/babel-preset-env
        [
            require.resolve('@babel/preset-env'),
            {
                modules: false,
                targets: browserslist_config_1.default,
            },
        ],
        [
            // https://babeljs.io/docs/en/babel-preset-typescript
            require.resolve('@babel/preset-typescript'),
            {
                isTSX: true,
                allExtensions: true,
            },
        ],
        [
            // https://babeljs.io/docs/en/babel-preset-react
            require.resolve('@babel/preset-react'),
            {
                development: process.env.NODE_ENV !== 'production',
            },
        ],
    ],
    plugins: [decoratorPlugin],
};
//# sourceMappingURL=index.js.map